@@ -14,6 +14,7 @@
 #    under the License.
 #
 from datetime import timedelta
+import requests
 import six
 
 from gnocchiclient import auth as gauth
@@ -30,9 +31,10 @@ from voluptuous import Required
 from voluptuous import Schema
 
 from cloudkitty import collector
+from cloudkitty.common import custom_session
 from cloudkitty import dataframe
-from cloudkitty import tzutils
 from cloudkitty import utils as ck_utils
+from cloudkitty.utils import tz as tzutils
 
 
 LOG = logging.getLogger(__name__)
@@ -67,6 +69,12 @@ collector_gnocchi_opts = [
         default='RegionOne',
         help='Region Name',
     ),
+    cfg.IntOpt(
+        'http_pool_maxsize',
+        default=requests.adapters.DEFAULT_POOLSIZE,
+        help='If the value is not defined, we use the value defined by '
+             'requests.adapters.DEFAULT_POOLSIZE',
+    )
 ]
 
 ks_loading.register_session_conf_options(cfg.CONF, COLLECTOR_GNOCCHI_OPTS)
@@ -75,6 +83,27 @@ cfg.CONF.register_opts(collector_gnocchi_opts, COLLECTOR_GNOCCHI_OPTS)
 
 CONF = cfg.CONF
 
+# According to 'gnocchi/rest/aggregates/operations.py#AGG_MAP' and
+# 'gnocchi/rest/aggregates/operations.py#AGG_MAP' the following are the basic
+# aggregation methods that one can use when configuring an aggregation
+# method in the archive policy in Gnocchi or using the aggregation API.
+BASIC_AGGREGATION_METHODS = set(('mean', 'sum', 'last', 'max', 'min', 'std',
+                                 'median', 'first', 'count'))
+for agg in list(BASIC_AGGREGATION_METHODS):
+    BASIC_AGGREGATION_METHODS.add("rate:%s" % agg)
+
+EXTRA_AGGREGATION_METHODS_FOR_ARCHIVE_POLICY = set(
+    (str(i) + 'pct' for i in six.moves.range(1, 100)))
+
+for agg in list(EXTRA_AGGREGATION_METHODS_FOR_ARCHIVE_POLICY):
+    EXTRA_AGGREGATION_METHODS_FOR_ARCHIVE_POLICY.add("rate:%s" % agg)
+
+# The aggregation method that one can use to configure the archive
+# policies also supports the 'pct' (percentile) operation. Therefore,
+# we also expose this as a configuration.
+VALID_AGGREGATION_METHODS_FOR_METRICS = BASIC_AGGREGATION_METHODS.union(
+    EXTRA_AGGREGATION_METHODS_FOR_ARCHIVE_POLICY)
+
 GNOCCHI_EXTRA_SCHEMA = {
     Required('extra_args'): {
         Required('resource_type'): All(str, Length(min=1)),
@@ -82,8 +111,10 @@ GNOCCHI_EXTRA_SCHEMA = {
         # This parameter permits to adapt the key of the resource identifier
         Required('resource_key', default='id'): All(str, Length(min=1)),
         Required('aggregation_method', default='max'):
-            In(['max', 'mean', 'min', 'rate:max', 'rate:mean', 'rate:min']),
-        Required('force_granularity', default=0): All(int, Range(min=0)),
+            In(VALID_AGGREGATION_METHODS_FOR_METRICS),
+        Required('re_aggregation_method', default='max'):
+            In(BASIC_AGGREGATION_METHODS),
+        Required('force_granularity', default=3600): All(int, Range(min=0)),
     },
 }
 
@@ -127,7 +158,9 @@ class GnocchiCollector(collector.BaseCollector):
 
         self._conn = gclient.Client(
             '1',
-            session_options={'auth': auth_plugin, 'verify': verify},
+            session=custom_session.create_custom_session(
+                {'auth': auth_plugin, 'verify': verify},
+                CONF.collector_gnocchi.http_pool_maxsize),
             adapter_options=adapter_options,
         )
 
@@ -265,7 +298,6 @@ class GnocchiCollector(collector.BaseCollector):
         """Get metric during the timeframe.
 
         :param metric_name: metric name to filter on.
-        :type resource_name: str
         :param start: Start of the timeframe.
         :param end: End of the timeframe if needed.
         :param project_id: Filter on a specific tenant/project.
@@ -273,43 +305,17 @@ class GnocchiCollector(collector.BaseCollector):
         :param q_filter: Append a custom filter.
         :type q_filter: list
         """
+        agg_kwargs = self.get_aggregation_api_arguments(end, metric_name,
+                                                        project_id,
+                                                        q_filter,
+                                                        start)
 
-        # Get gnocchi specific conf
-        extra_args = self.conf[metric_name]['extra_args']
-
-        # get resource type
-        resource_type = extra_args['resource_type']
-        scope_key = CONF.collect.scope_key
-
-        # build search query using resource type and project_id if provided
-        query_parameters = list()
-        query_parameters.append(
-            self.gen_filter(cop="=", type=resource_type))
-
-        if project_id:
-            kwargs = {scope_key: project_id}
-            query_parameters.append(self.gen_filter(**kwargs))
-        if q_filter:
-            query_parameters.append(q_filter)
-
-        # build aggregration operation
-        op = ["aggregate", extra_args['aggregation_method'],
-              ["metric", metric_name, extra_args['aggregation_method']]]
-
-        # get groupby
-        groupby = self.conf[metric_name]['groupby']
-
-        agg_kwargs = {
-            'resource_type': resource_type,
-            'start': start,
-            'stop': end,
-            'groupby': groupby,
-            'search': self.extend_filter(*query_parameters),
-        }
-        if extra_args['force_granularity'] > 0:
-            agg_kwargs['granularity'] = extra_args['force_granularity']
+        op = self.build_operation_command(metric_name)
         try:
-            return self._conn.aggregates.fetch(op, **agg_kwargs)
+            measurements = self._conn.aggregates.fetch(op, **agg_kwargs)
+            LOG.debug("Measurements [%s] received with operation [%s] and "
+                      "arguments [%s].", measurements, op, agg_kwargs)
+            return measurements
         except (gexceptions.MetricNotFound, gexceptions.BadRequest) as e:
             # FIXME(peschk_l): gnocchiclient seems to be raising a BadRequest
             # when it should be raising MetricNotFound
@@ -320,6 +326,55 @@ class GnocchiCollector(collector.BaseCollector):
                         'current cycle.'.format(scope=project_id, err=e))
             return []
 
+    def get_aggregation_api_arguments(self, end, metric_name, project_id,
+                                      q_filter, start):
+        extra_args = self.conf[metric_name]['extra_args']
+        resource_type = extra_args['resource_type']
+
+        query_parameters = self.build_query_parameters(project_id, q_filter,
+                                                       resource_type)
+        agg_kwargs = {
+            'resource_type': resource_type,
+            'start': start,
+            'stop': end,
+            'groupby': self.conf[metric_name]['groupby'],
+            'search': self.extend_filter(*query_parameters),
+        }
+
+        force_granularity = extra_args['force_granularity']
+        if force_granularity > 0:
+            agg_kwargs['granularity'] = force_granularity
+
+        re_aggregation_method = extra_args['re_aggregation_method']
+        if re_aggregation_method.startswith('rate:'):
+            agg_kwargs['start'] = start - timedelta(seconds=force_granularity)
+            LOG.debug("Re-aggregation method for metric [%s] configured as"
+                      " [%s]. Therefore, we need two data points. Start date"
+                      " modified from [%s] to [%s].", metric_name,
+                      re_aggregation_method, start, agg_kwargs['start'])
+
+        return agg_kwargs
+
+    def build_query_parameters(self, project_id, q_filter, resource_type):
+        query_parameters = list()
+        query_parameters.append(
+            self.gen_filter(cop="=", type=resource_type))
+        if project_id:
+            scope_key = CONF.collect.scope_key
+            kwargs = {scope_key: project_id}
+            query_parameters.append(self.gen_filter(**kwargs))
+        if q_filter:
+            query_parameters.append(q_filter)
+        return query_parameters
+
+    def build_operation_command(self, metric_name):
+        extra_args = self.conf[metric_name]['extra_args']
+
+        re_aggregation_method = extra_args['re_aggregation_method']
+        op = ["aggregate", re_aggregation_method,
+              ["metric", metric_name, extra_args['aggregation_method']]]
+        return op
+
     def _format_data(self, metconf, data, resources_info=None):
         """Formats gnocchi data to CK data.
 
