@@ -27,7 +27,7 @@ class MetricConfigValidationTest(tests.TestCase):
         'metrics': {
             'metric_one': {
                 'groupby': ['one'],
-                'metadata': ['one'],
+                'metadata': ['two'],
                 'unit': 'u',
             }
         }
@@ -36,7 +36,7 @@ class MetricConfigValidationTest(tests.TestCase):
     base_output = {
         'metric_one': {
             'groupby': ['one'],
-            'metadata': ['one'],
+            'metadata': ['two'],
             'unit': 'u',
             'factor': 1,
             'offset': 0,
@@ -69,11 +69,9 @@ class MetricConfigValidationTest(tests.TestCase):
         expected_output = copy.deepcopy(self.base_output)
         expected_output['metric_one']['groupby'] += ['project_id', 'id']
         expected_output['metric_one']['extra_args'] = {
-            'aggregation_method': 'max',
-            'force_granularity': 0,
-            'resource_type': 'res',
-            'resource_key': 'id',
-        }
+            'aggregation_method': 'max', 're_aggregation_method': 'max',
+            'force_granularity': 3600, 'resource_type': 'res',
+            'resource_key': 'id'}
 
         self.assertEqual(
             collector.gnocchi.GnocchiCollector.check_configuration(data),
@@ -155,14 +153,26 @@ class MetricConfigValidationTest(tests.TestCase):
         data = copy.deepcopy(self.base_data)
         data['metrics']['metric_one']['extra_args'] = {
             'aggregation_method': 'max',
+            'query_function': 'abs',
+            'range_function': 'delta',
         }
         expected_output = copy.deepcopy(self.base_output)
         expected_output['metric_one']['groupby'].append('project_id')
         expected_output['metric_one']['extra_args'] = {
             'aggregation_method': 'max',
+            'query_function': 'abs',
+            'range_function': 'delta',
         }
 
         self.assertEqual(
             collector.prometheus.PrometheusCollector.check_configuration(data),
             expected_output,
         )
+
+    def test_check_duplicates(self):
+        data = copy.deepcopy(self.base_data)
+        for metric_name, metric in data['metrics'].items():
+            metric['metadata'].append('one')
+            self.assertRaises(
+                collector.InvalidConfiguration,
+                collector.check_duplicates, metric_name, metric)
