@@ -18,10 +18,10 @@ import collections
 import datetime
 import decimal
 import os
+from unittest import mock
 
 from dateutil import tz
 from gabbi import fixture
-import mock
 from oslo_config import cfg
 from oslo_config import fixture as conf_fixture
 from oslo_db.sqlalchemy import utils
@@ -37,6 +37,8 @@ import wsmeext.pecan as wsme_pecan
 
 from cloudkitty.api import app
 from cloudkitty.api import middleware
+from cloudkitty.api.v2.dataframes import dataframes as v2_api_dataframes
+from cloudkitty.api.v2.summary import summary as v2_api_summary
 from cloudkitty import dataframe
 from cloudkitty import db
 from cloudkitty.db import api as ck_db_api
@@ -48,11 +50,11 @@ from cloudkitty import storage_state
 from cloudkitty import tests
 from cloudkitty.tests.storage.v2 import influx_utils
 from cloudkitty.tests import utils as test_utils
-from cloudkitty import tzutils
 from cloudkitty import utils as ck_utils
+from cloudkitty.utils import tz as tzutils
 
 
-INITIAL_DT = datetime.datetime(2015, 1, 1, tzinfo=tz.UTC)
+INITIAL_DT = datetime.datetime(2015, 1, 1, tzinfo=tz.tzutc())
 
 
 class UUIDFixture(fixture.GabbiFixture):
@@ -375,7 +377,7 @@ class StorageDataFixture(BaseStorageDataFixture):
 
 class NowStorageDataFixture(BaseStorageDataFixture):
     def initialize_data(self):
-        dt = tzutils.get_month_start(naive=True).replace(tzinfo=tz.UTC)
+        dt = tzutils.get_month_start(naive=True).replace(tzinfo=tz.tzutc())
         hour_delta = datetime.timedelta(seconds=3600)
         limit = dt + hour_delta * 12
         while dt < limit:
@@ -459,6 +461,8 @@ class NowInfluxStorageDataFixture(NowStorageDataFixture):
             new=lambda **kw: st,
         )
         self._get_storage_patch.start()
+        v2_api_summary.Summary.reload()
+        v2_api_dataframes.DataFrameList.reload()
 
         super(NowInfluxStorageDataFixture, self).start_fixture()
 
@@ -485,6 +489,8 @@ class InfluxStorageDataFixture(StorageDataFixture):
             new=lambda **kw: st,
         )
         self._get_storage_patch.start()
+        v2_api_summary.Summary.reload()
+        v2_api_dataframes.DataFrameList.reload()
 
         super(InfluxStorageDataFixture, self).start_fixture()
 
@@ -495,7 +501,7 @@ class InfluxStorageDataFixture(StorageDataFixture):
 class UTCFixture(fixture.GabbiFixture):
     """Set the local timezone to UTC"""
     def start_fixture(self):
-        self._tzmock = mock.patch('cloudkitty.tzutils._LOCAL_TZ', tz.UTC)
+        self._tzmock = mock.patch('cloudkitty.utils.tz._LOCAL_TZ', tz.tzutc())
         self._tzmock.start()
 
     def stop_fixture(self):
