@@ -16,8 +16,8 @@
 import copy
 import datetime
 import decimal
+from unittest import mock
 
-import mock
 from oslo_utils import uuidutils
 
 from cloudkitty import dataframe
